==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/brandOpenShop/BatchTaskInfoVO.java <==
package eleme.openapi.sdk.api.entity.brandOpenShop;

import eleme.openapi.sdk.api.enumeration.*;
import eleme.openapi.sdk.api.entity.brandOpenShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class BatchTaskInfoVO{

    /**
     * 商户名
     */
    private String customerName;
    public String getCustomerName() {
        return customerName;
    }
    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    
    /**
     * 饿了么侧开店任务id
     */
    private String batchId;
    public String getBatchId() {
        return batchId;
    }
    public void setBatchId(String batchId) {
        this.batchId = batchId;
    }
    
    /**
     * 开店任务名
     */
    private String batchTaskName;
    public String getBatchTaskName() {
        return batchTaskName;
    }
    public void setBatchTaskName(String batchTaskName) {
        this.batchTaskName = batchTaskName;
    }
    
    /**
     * 选择的连锁节点id
     */
    private Long nodeId;
    public Long getNodeId() {
        return nodeId;
    }
    public void setNodeId(Long nodeId) {
        this.nodeId = nodeId;
    }
    
    /**
     * 选择的连锁节点名称
     */
    private String nodeName;
    public String getNodeName() {
        return nodeName;
    }
    public void setNodeName(String nodeName) {
        this.nodeName = nodeName;
    }
    
    /**
     * 选择的品牌名称
     */
    private String brandName;
    public String getBrandName() {
        return brandName;
    }
    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    
    /**
     * 选择的品牌id
     */
    private Long brandId;
    public Long getBrandId() {
        return brandId;
    }
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    
    /**
     * 开店任务上传的logo图
     */
    private ImageDTO logo;
    public ImageDTO getLogo() {
        return logo;
    }
    public void setLogo(ImageDTO logo) {
        this.logo = logo;
    }
    
    /**
     * 主营品类
     */
    private CategoryInfoDTO mainCategory;
    public CategoryInfoDTO getMainCategory() {
        return mainCategory;
    }
    public void setMainCategory(CategoryInfoDTO mainCategory) {
        this.mainCategory = mainCategory;
    }
    
    /**
     * 副营品类
     */
    private CategoryInfoDTO subCategory;
    public CategoryInfoDTO getSubCategory() {
        return subCategory;
    }
    public void setSubCategory(CategoryInfoDTO subCategory) {
        this.subCategory = subCategory;
    }
    
    /**
     * 开店任务状态
     */
    private String status;
    public String getStatus() {
        return status;
    }
    public void setStatus(String status) {
        this.status = status;
    }
    
    /**
     * 接收店铺账户手机号
     */
    private String receiveAccountPhone;
    public String getReceiveAccountPhone() {
        return receiveAccountPhone;
    }
    public void setReceiveAccountPhone(String receiveAccountPhone) {
        this.receiveAccountPhone = receiveAccountPhone;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/brandOpenShop/BatchTaskInfoVO.java <==
package eleme.openapi.sdk.api.entity.brandOpenShop;

import eleme.openapi.sdk.api.enumeration.brandOpenShop.*;
import eleme.openapi.sdk.api.entity.brandOpenShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class BatchTaskInfoVO{

    /**
     * 商户名
     */
    private String customerName;
    public String getCustomerName() {
        return customerName;
    }
    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    
    /**
     * 饿了么侧开店任务id
     */
    private String batchId;
    public String getBatchId() {
        return batchId;
    }
    public void setBatchId(String batchId) {
        this.batchId = batchId;
    }
    
    /**
     * 开店任务名
     */
    private String batchTaskName;
    public String getBatchTaskName() {
        return batchTaskName;
    }
    public void setBatchTaskName(String batchTaskName) {
        this.batchTaskName = batchTaskName;
    }
    
    /**
     * 选择的连锁节点id
     */
    private Long nodeId;
    public Long getNodeId() {
        return nodeId;
    }
    public void setNodeId(Long nodeId) {
        this.nodeId = nodeId;
    }
    
    /**
     * 选择的连锁节点名称
     */
    private String nodeName;
    public String getNodeName() {
        return nodeName;
    }
    public void setNodeName(String nodeName) {
        this.nodeName = nodeName;
    }
    
    /**
     * 选择的品牌名称
     */
    private String brandName;
    public String getBrandName() {
        return brandName;
    }
    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    
    /**
     * 选择的品牌id
     */
    private Long brandId;
    public Long getBrandId() {
        return brandId;
    }
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    
    /**
     * 开店任务上传的logo图
     */
    private ImageDTO logo;
    public ImageDTO getLogo() {
        return logo;
    }
    public void setLogo(ImageDTO logo) {
        this.logo = logo;
    }
    
    /**
     * 主营品类
     */
    private CategoryInfoDTO mainCategory;
    public CategoryInfoDTO getMainCategory() {
        return mainCategory;
    }
    public void setMainCategory(CategoryInfoDTO mainCategory) {
        this.mainCategory = mainCategory;
    }
    
    /**
     * 副营品类
     */
    private CategoryInfoDTO subCategory;
    public CategoryInfoDTO getSubCategory() {
        return subCategory;
    }
    public void setSubCategory(CategoryInfoDTO subCategory) {
        this.subCategory = subCategory;
    }
    
    /**
     * 开店任务状态
     */
    private String status;
    public String getStatus() {
        return status;
    }
    public void setStatus(String status) {
        this.status = status;
    }
    
    /**
     * 接收店铺账户手机号
     */
    private String receiveAccountPhone;
    public String getReceiveAccountPhone() {
        return receiveAccountPhone;
    }
    public void setReceiveAccountPhone(String receiveAccountPhone) {
        this.receiveAccountPhone = receiveAccountPhone;
    }
    
}
